@@ -79,7 +79,11 @@ int imap_read_headers (IMAP_DATA* idata, int msgbegin, int msgend)
    * as they come in. */
   mutt_mktemp (tempfile);
   if (!(fp = safe_fopen (tempfile, "w+")))
+  {
+    mutt_error (_("Could not create temporary file %s"), tempfile);
+    mutt_sleep (2);
     return -1;
+  }
   unlink (tempfile);
 
   /* make sure context has room to hold the mailbox */
@@ -506,8 +510,8 @@ int imap_append_message (CONTEXT *ctx, MESSAGE *msg)
 int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
 {
   IMAP_DATA* idata;
-  char buf[HUGE_STRING];
-  char cmd[LONG_STRING];
+  BUFFER cmd;
+  char uid[11];
   char mbox[LONG_STRING];
   char mmbox[LONG_STRING];
   int rc;
@@ -536,7 +540,10 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
     return 1;
   }
   
-  imap_fix_path (idata, mx.mbox, cmd, sizeof (cmd));
+  imap_fix_path (idata, mx.mbox, mbox, sizeof (mbox));
+
+  memset (&cmd, 0, sizeof (cmd));
+  mutt_buffer_addstr (&cmd, "UID COPY ");
 
   /* Null HEADER* means copy tagged messages */
   if (!h)
@@ -552,26 +559,28 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
 	return 1;
       }
     }
-    
-    rc = imap_make_msg_set (idata, buf, sizeof (buf), M_TAG, 0);
+
+    rc = imap_make_msg_set (idata, &cmd, M_TAG, 0);
     if (!rc)
     {
       dprint (1, (debugfile, "imap_copy_messages: No messages tagged\n"));
       goto fail;
     }
-    mutt_message (_("Copying %d messages to %s..."), rc, cmd);
+    mutt_message (_("Copying %d messages to %s..."), rc, mbox);
   }
   else
   {
-    mutt_message (_("Copying message %d to %s..."), h->index+1, cmd);
-    snprintf (buf, sizeof (buf), "%u", HEADER_DATA (h)->uid);
+    mutt_message (_("Copying message %d to %s..."), h->index+1, mbox);
+    snprintf (uid, sizeof (uid), "%u", HEADER_DATA (h)->uid);
+    mutt_buffer_addstr (&cmd, uid);
   }
 
   /* let's get it on */
-  strncpy (mbox, cmd, sizeof (mbox));
-  imap_munge_mbox_name (mmbox, sizeof (mmbox), cmd);
-  snprintf (cmd, sizeof (cmd), "UID COPY %s %s", buf, mmbox);
-  rc = imap_exec (idata, cmd, IMAP_CMD_FAIL_OK);
+  mutt_buffer_addstr (&cmd, " ");
+  imap_munge_mbox_name (mmbox, sizeof (mmbox), mbox);
+  mutt_buffer_addstr (&cmd, mmbox);
+
+  rc = imap_exec (idata, cmd.data, IMAP_CMD_FAIL_OK);
   if (rc == -2)
   {
     /* bail out if command failed for reasons other than nonexistent target */
@@ -581,8 +590,8 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
       goto fail;
     }
     dprint (2, (debugfile, "imap_copy_messages: server suggests TRYCREATE\n"));
-    snprintf (buf, sizeof (buf), _("Create %s?"), mbox);
-    if (option (OPTCONFIRMCREATE) && mutt_yesorno (buf, 1) < 1)
+    snprintf (mmbox, sizeof (mmbox), _("Create %s?"), mbox);
+    if (option (OPTCONFIRMCREATE) && mutt_yesorno (mmbox, 1) < 1)
     {
       mutt_clear_error ();
       goto fail;
@@ -591,7 +600,7 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
       goto fail;
 
     /* try again */
-    rc = imap_exec (idata, cmd, 0);
+    rc = imap_exec (idata, cmd.data, 0);
   }
   if (rc != 0)
   {
@@ -620,10 +629,14 @@ int imap_copy_messages (CONTEXT* ctx, HEADER* h, char* dest, int delete)
     }
   }
 
+  if (cmd.data)
+    FREE (&cmd.data);
   FREE (&mx.mbox);
   return 0;
 
  fail:
+  if (cmd.data)
+    FREE (&cmd.data);
   FREE (&mx.mbox);
   return -1;
 }
