@@ -396,6 +396,10 @@ int mx_get_magic (const char *path)
     if (access (tmp, F_OK) == 0)
       return (M_MH);
 
+    snprintf (tmp, sizeof (tmp), "%s/.mew-cache", path);
+    if (access (tmp, F_OK) == 0)
+      return (M_MH);
+
     /* 
      * ok, this isn't an mh folder, but mh mode can be used to read
      * Usenet news from the spool. ;-) 
@@ -1267,6 +1271,13 @@ MESSAGE *mx_open_new_message (CONTEXT *dest, HEADER *hdr, int flags)
   msg->magic = dest->magic;
   msg->write = 1;
 
+  if (hdr)
+  {
+    msg->flags.flagged = hdr->flagged;
+    msg->flags.replied = hdr->replied;
+    msg->flags.read    = hdr->read;
+  }
+  
   if (func (msg, dest, hdr) == 0)
   {
     if (dest->magic == M_MMDF)
